@@ -51,4 +51,4 @@ def test_html_tag(tag):
     """
     tag_data = json_data[tag]
     expected_html = html_data[tag]
-    assert tiptapy.to_html(tag_data) == expected_html
+    assert tiptapy.to_html(tag_data) == expected_html.strip()
